@@ -9,6 +9,9 @@ from ...models.osidb_api_v1_affects_update_response_200 import (
 )
 from ...types import UNSET, Response, Unset
 
+QUERY_PARAMS = {}
+REQUEST_BODY_TYPE = Affect
+
 
 def _get_kwargs(
     uuid: str,
