@@ -4,13 +4,13 @@ from typing import Any, Dict, List, Type, TypeVar, Union
 import attr
 from dateutil.parser import isoparse
 
-from ..types import UNSET, Unset
+from ..types import UNSET, OSIDBModel, Unset
 
 T = TypeVar("T", bound="AuthTokenRetrieveResponse200")
 
 
 @attr.s(auto_attribs=True)
-class AuthTokenRetrieveResponse200:
+class AuthTokenRetrieveResponse200(OSIDBModel):
     """ """
 
     access: Union[Unset, str] = UNSET
@@ -81,6 +81,17 @@ class AuthTokenRetrieveResponse200:
         auth_token_retrieve_response_200.additional_properties = d
         return auth_token_retrieve_response_200
 
+    @staticmethod
+    def get_fields():
+        return {
+            "access": str,
+            "dt": datetime.datetime,
+            "env": str,
+            "refresh": str,
+            "revision": str,
+            "version": str,
+        }
+
     @property
     def additional_keys(self) -> List[str]:
         return list(self.additional_properties.keys())
