@@ -13,13 +13,13 @@ from ..models.collectors_api_v1_status_retrieve_response_200_collectors_item_err
 from ..models.collectors_api_v1_status_retrieve_response_200_collectors_item_state import (
     CollectorsApiV1StatusRetrieveResponse200CollectorsItemState,
 )
-from ..types import UNSET, Unset
+from ..types import UNSET, OSIDBModel, Unset
 
 T = TypeVar("T", bound="CollectorsApiV1StatusRetrieveResponse200CollectorsItem")
 
 
 @attr.s(auto_attribs=True)
-class CollectorsApiV1StatusRetrieveResponse200CollectorsItem:
+class CollectorsApiV1StatusRetrieveResponse200CollectorsItem(OSIDBModel):
     """ """
 
     data: Union[
@@ -148,6 +148,18 @@ class CollectorsApiV1StatusRetrieveResponse200CollectorsItem:
         )
         return collectors_api_v1_status_retrieve_response_200_collectors_item
 
+    @staticmethod
+    def get_fields():
+        return {
+            "data": CollectorsApiV1StatusRetrieveResponse200CollectorsItemData,
+            "depends_on": List[str],
+            "error": CollectorsApiV1StatusRetrieveResponse200CollectorsItemError,
+            "is_complete": bool,
+            "data_models": List[str],
+            "state": CollectorsApiV1StatusRetrieveResponse200CollectorsItemState,
+            "updated_until": datetime.datetime,
+        }
+
     @property
     def additional_keys(self) -> List[str]:
         return list(self.additional_properties.keys())
