@@ -2,13 +2,13 @@ from typing import Any, Dict, List, Type, TypeVar
 
 import attr
 
-from ..types import UNSET
+from ..types import UNSET, OSIDBModel
 
 T = TypeVar("T", bound="EPSS")
 
 
 @attr.s(auto_attribs=True)
-class EPSS:
+class EPSS(OSIDBModel):
     """ """
 
     cve: str
@@ -43,6 +43,13 @@ class EPSS:
         epss.additional_properties = d
         return epss
 
+    @staticmethod
+    def get_fields():
+        return {
+            "cve": str,
+            "epss": float,
+        }
+
     @property
     def additional_keys(self) -> List[str]:
         return list(self.additional_properties.keys())
