@@ -4,13 +4,13 @@ from typing import Any, Dict, List, Type, TypeVar, Union
 import attr
 from dateutil.parser import isoparse
 
-from ..types import UNSET, Unset
+from ..types import UNSET, OSIDBModel, Unset
 
 T = TypeVar("T", bound="ExploitsApiV1StatusRetrieveResponse200")
 
 
 @attr.s(auto_attribs=True)
-class ExploitsApiV1StatusRetrieveResponse200:
+class ExploitsApiV1StatusRetrieveResponse200(OSIDBModel):
     """ """
 
     dt: Union[Unset, datetime.datetime] = UNSET
@@ -88,6 +88,18 @@ class ExploitsApiV1StatusRetrieveResponse200:
         exploits_api_v1_status_retrieve_response_200.additional_properties = d
         return exploits_api_v1_status_retrieve_response_200
 
+    @staticmethod
+    def get_fields():
+        return {
+            "dt": datetime.datetime,
+            "env": str,
+            "exploits_count": int,
+            "exploits_count_relevant": int,
+            "last_exploit": int,
+            "revision": str,
+            "version": str,
+        }
+
     @property
     def additional_keys(self) -> List[str]:
         return list(self.additional_properties.keys())
