@@ -6,8 +6,8 @@ class MetaTypeEnum(str, Enum):
     REFERENCE = "REFERENCE"
     ACKNOWLEDGMENT = "ACKNOWLEDGMENT"
     EXPLOIT = "EXPLOIT"
-    CSAW = "CSAW"
-    CSAW_LITE = "CSAW_LITE"
+    MAJOR_INCIDENT = "MAJOR_INCIDENT"
+    MAJOR_INCIDENT_LITE = "MAJOR_INCIDENT_LITE"
     REQUIRES_DOC_TEXT = "REQUIRES_DOC_TEXT"
     NIST_CVSS_VALIDATION = "NIST_CVSS_VALIDATION"
     NEED_INFO = "NEED_INFO"
