@@ -7,13 +7,13 @@ from dateutil.parser import isoparse
 from ..models.osidb_whoami_retrieve_response_200_profile import (
     OsidbWhoamiRetrieveResponse200Profile,
 )
-from ..types import UNSET, Unset
+from ..types import UNSET, OSIDBModel, Unset
 
 T = TypeVar("T", bound="OsidbWhoamiRetrieveResponse200")
 
 
 @attr.s(auto_attribs=True)
-class OsidbWhoamiRetrieveResponse200:
+class OsidbWhoamiRetrieveResponse200(OSIDBModel):
     """ """
 
     dt: Union[Unset, datetime.datetime] = UNSET
@@ -109,6 +109,19 @@ class OsidbWhoamiRetrieveResponse200:
         osidb_whoami_retrieve_response_200.additional_properties = d
         return osidb_whoami_retrieve_response_200
 
+    @staticmethod
+    def get_fields():
+        return {
+            "dt": datetime.datetime,
+            "email": str,
+            "env": str,
+            "groups": List[str],
+            "profile": OsidbWhoamiRetrieveResponse200Profile,
+            "revision": str,
+            "username": str,
+            "version": str,
+        }
+
     @property
     def additional_keys(self) -> List[str]:
         return list(self.additional_properties.keys())
