@@ -2,13 +2,13 @@ from typing import Any, Dict, List, Type, TypeVar
 
 import attr
 
-from ..types import UNSET
+from ..types import UNSET, OSIDBModel
 
 T = TypeVar("T", bound="TokenVerify")
 
 
 @attr.s(auto_attribs=True)
-class TokenVerify:
+class TokenVerify(OSIDBModel):
     """ """
 
     token: str
@@ -53,6 +53,12 @@ class TokenVerify:
         token_verify.additional_properties = d
         return token_verify
 
+    @staticmethod
+    def get_fields():
+        return {
+            "token": str,
+        }
+
     @property
     def additional_keys(self) -> List[str]:
         return list(self.additional_properties.keys())
